# 个人工具库

## 一、介绍

    个人用库，汇集各类工具以及自己的工具代码。便于快速安装个性化的依赖。

## 二、安装

## 三、主要内容

## 四、相关依赖

## 五、开发环境说明

    - Python版本：3.10
    - 使用`conda`管理依赖，保证开发环境一致性
    - 初始化项目：`pip install -r requirements.txt`安装依赖
